@@ -14,7 +14,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Script::Daemon - Daemon Script
+Mojoicious::Script::Daemon - Daemon Script
 
 =head1 SYNOPSIS
 
